@@ -26,14 +26,25 @@ for afunc in "${ALLFUNCS[@]}"; do
 		# failed
 		mv whitelist.ori whitelist.txt
 		echo $afunc >> blacklist.txt
+		echo "Function '$afunc' goes to the blacklist ..."
 	else
 		cp whitelist.txt whitelist.ori
+		echo "Function '$afunc' goes to the whitelist ..."
 	fi
 done
 
 mv whitelist.txt whitelist.txt.final
 mv blacklist.txt blacklist.txt.final
 
-echo "$0 : done, set the contents of whitelist.txt.final and blacklist.txt.final into '${WHEREAMI}/build-gcc-builtins-package.pl'"
-echo "then run '${WHEREAMI}/build-gcc-builtins-package.pl' and then perl Makefile.PL && make all && make test"
+echo "$0 : done."
+echo "If you want to add whitelisted/blacklisted functions then edit '${WHEREAMI}/build-gcc-builtins-package.pl'."
+echo
+echo "Normally, you do not need to edit anything. The whitelisted functions will be read from file automatically and the blacklisted functions are already set in that file and should not be needing changes unless GCC adds other builtins."
+echo
+echo "Then run '${WHEREAMI}/build-gcc-builtins-package.pl' and then perl Makefile.PL && make all && make test"
+echo
 echo "If any of the test files above t/666-\*.t fails, copy the expected value into '${WHEREAMI}/build-gcc-builtins-package.pl' (into '%T_EXPECTED_RESULTS') and retry."
+echo
+echo
+echo "$0 : so, all done, it seems all was successful. Now run what is mentioned above."
+echo
